@@ -1,5 +1,5 @@
 package HTTP::Tiny::Paranoid;
-$HTTP::Tiny::Paranoid::VERSION = '0.03';
+$HTTP::Tiny::Paranoid::VERSION = '0.04';
 use strict;
 use warnings;
 
@@ -19,10 +19,11 @@ around _open_handle => sub {
     my $self = shift;
 
     my ($req, $scheme, $host, $port) = @_;
-    my (undef, $error) = $dns->resolve($host);
+    my ($ips, $error) = $dns->resolve($host);
     die "$host: $error\n" if defined $error;
+    die "$host: no IP address found\n" unless @$ips;
 
-    $self->$next(@_);
+    $self->$next($req, $scheme, $ips->[0], $port);
 };
 
 1;
@@ -38,7 +39,7 @@ HTTP::Tiny::Paranoid - A safer HTTP::Tiny
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
